# -*- coding: iso-8859-1 -*-
"""
Programme du couplage entre HOMARD et Code_Aster
"""
__revision__ = "V2.0"
#
import os
import string
import shutil
#
########################## Debut de la fonction ##################################
#
def aster_homard_4 (environnement, dict_arguments, variables_conf, code_retour_exec) :
#
  """
   Arguments :
     1. Dictionnaire de l'environnement
     2. Dictionnaire des arguments generaux
     3. Dictionnaire des variables de configuration
     4. Code de retour de l'execution de HOMARD
  """
#
# 1. code de retour :
  blabla = "\nDans " + __name__ + " :"
  messages_erreur = { 0 : "Tout va bien", 
                      2 : "Probleme de copie de fichier." }

#
#  print blabla, environnement, dict_arguments, variables_conf, code_retour_exec
  erreur = 0
  verbose = dict_arguments["verbose"]
  modehoma = variables_conf["ModeHOMA"]
  nivinf = dict_arguments ["nivinf"]
  fic_conf = environnement["fic_conf"]
#
  if verbose :
    print blabla
#
# 2. Archivage des fichiers
# 2.1. Pralable
#
  niter = string.atoi(variables_conf["NumeIter"])
  aux_niter = variables_conf["NumeIter"]
  if niter < 10 :
    aux_niter = "0" + aux_niter
#
  niterp1 = niter + 1
  aux_niterp1 = str(niterp1)
  if niterp1 < 10 :
    aux_niterp1 = "0" + aux_niterp1
#
  if modehoma == 1 :
    action = "avad"
  else :
    action = "homa"
#
  if verbose :
    print ".. Fichiers prsents dans le rpertoire d'excution de HOMARD :\n", os.listdir(os.curdir)
#
# 2.2. La liste standard :
#      . si le mode est verbeux
#      . si le niveau d'information est > 1
#      . s'il y a eu un probleme a l'execution
#
  if ( verbose or nivinf > 1 or code_retour_exec != 0 ) :
    ecrire_listestd = 1
    liste = [variables_conf["ListeStd"]]
  else :
    ecrire_listestd = 0
    liste = [ ]
#
# 2.3. Les fichiers de bilan
#
  if ( niter == 0 ) :
    liste.append(action+".00.bilan")
    if verbose :
      liste.append("verif_"+action+".00.bilan")
#
  for saux in ["noeu", "aret", "tria", "tetr", "quad", "pyra", "hexa", "pent"] :
    liste.append("indic."+saux+"."+aux_niter+".hist")
#
  liste.append("apad."+aux_niterp1+".bilan")
  if verbose :
    liste.append("verif_apad."+aux_niterp1+".bilan")
#
# 2.4. Le fichier de configuration si il y a eu un probleme a l'execution
#
  if ( code_retour_exec != 0 ) :
    liste.append(fic_conf)
#  print liste
#
# 2.5. Impression sur la sortie standard d'Aster
#      Remarque : je ne sais pas mieux faire que de tout lire et d'imprimer ensuite ...
#
  for fic in liste :
    if os.path.isfile (fic) :
      if verbose :
        print ".... fichier :", fic
      fichier = open (fic, 'r')
      tout = fichier.read()
      fichier.close()
      print tout
#
# 2.6. Affichage des mesures de temps de calcul, si le fichier complet n'a pas dej t crit
#
  if not ecrire_listestd :
    message = "\n.......................................................................\n"
    fic = variables_conf["ListeStd"]
    if os.path.isfile (fic) :
      fichier = open (fic, 'r')
      tout = fichier.readlines()
      fichier.close()
      for ligne in tout :
        chaines = string.split(ligne)
        jaux = len(chaines)
        if jaux >= 8 :
          if chaines[0] == ":" :
            if chaines[1] == "Temps" or chaines[1] == "Total" :
              message = message + ligne
    message = message + ":.....................................................................:\n"
    print message
#
# 2.7. Archivage du fichier de configuration
#      Remarque : il faut copier et non pas renommer car on en a encore besoin
#
  if dict_arguments["PERSO"] == "oui" :
    if modehoma == 1 :
      saux = ".vers."+aux_niterp1
    else :
      saux = ".info"
    codret_partiel = [0]
    try :
      fic = fic_conf+"."+aux_niter+saux
      shutil.copyfile(fic_conf, fic)
    except os.error, codret_partiel :
      print "Probleme pour copier le fichier", fic_conf, "dans", fic
      print "Code d'erreur de copyfile : ", codret_partiel[0], ":", codret_partiel[1]
      erreur = 2
#
# 3. La fin
#
  if erreur :
    print blabla, messages_erreur[erreur]
#
  return erreur
#
##########################  Fin de la fonction  ##################################
#
##########################       Auto-test      ##################################
#
if __name__ == '__main__' :
#
  from aster_homard_utilitaires import verif
#
  e1 = { "fic_donn" : "DONN", "fic_conf" : "HOMARD.Configuration" }
  a1 = {'PERSO': "non", 'nivinf': 2 }
  v1 = {'NumeIter': '3', 'PPBasFic': 'INFO', 'ModeHOMA': 2, 'ListeStd': 'aster_homard_5.py' }
  l1_refe = 0
  l1_calc = aster_homard_4 (e1, a1, v1, 0)
  verif ("Test sur l1", l1_refe, l1_calc)
#
  fic_conf_test = "HOMARD.Configuration"
  fichier_test = open (fic_conf_test, 'w')
  s = "ModeHOMA 1\n"
  fichier_test.write(s)
  fichier_test.close()
  e2 = { "fic_donn" : "DONN", "fic_conf" : fic_conf_test }
  a2 = {'PERSO': "oui", 'nivinf': 1 }
  v2 = {'NumeIter': '3', 'PPBasFic': 'INFO', 'ModeHOMA': 2, 'ListeStd': 'gabuzome' }
  l2_refe = 0
  l2_calc = aster_homard_4 (e2, a2, v2, 8)
  verif ("Test sur l2", l2_refe, l2_calc)
  os.remove(fic_conf_test)
  os.remove(fic_conf_test+".3.info")
