# -*- coding: iso-8859-1 -*-
"""
Programme du couplage entre HOMARD et Code_Aster
"""
__revision__ = "V2.0"
#
import os
import sys
#
from aster_homard_1             import aster_homard_1
from aster_homard_2             import aster_homard_2
from aster_homard_3             import aster_homard_3
from aster_homard_4             import aster_homard_4
from aster_homard_5             import aster_homard_5
from aster_homard_6             import aster_homard_6
from aster_homard_7             import aster_homard_7
from aster_homard_8             import aster_homard_8
#
def aster_homard (arguments) :
#
  """docstring"""
#
#   Arguments :
#     1. Repertoire de reference de HOMARD sur la machine
#     2. Type de fonctionnement :
#        1 : creation du repertoire de calcul
#        2 : execution de homard
#     3. Sous-repertoire dans lequel aura lieu l'execution de homard
#     4. Version de homard
#     5. Niveau d'information au sens ASTER
#     Puis, pour chaque fichier parmi :
#              . maillage a l'etape n
#              . maillage a l'etape n+1
#              . solution a l'etape n
#              . solution a l'etape n+1
#              . indicateur d'erreur
#        . 0, si pas de fichier
#          numero d'unite logique aster correspondant au fichier, si fichier
#     N. rien, si version publique de HOMARD
#        -PERSO, si version personnelle
#     N+1. repertoire de base HOMARD si version personnelle
#
#   Remarque : ces arguments sont transmis sous forme d'une chane de caractres
#
# 1. Initialisation
#
  message_erreur = None
#
###  blabla = "\nDans " + sys.argv[0] + ", avant appel a aster_homard_"
#
  rep_calc_aster = os.getcwd()
#
#  constantes :
  environnement = { "fic_donn" : "DONN", 
                    "fic_conf" : "HOMARD.Configuration", 
                    "rep_calc_aster" : rep_calc_aster }
#
  l_arguments = arguments.split()
#
# 2. Decodage des arguments 2 et 22 :
#
#  print blabla, "1, :", "\nArguments :", l_arguments[1:3]
  dict_arguments = aster_homard_1 (l_arguments[1:3])
#  print "dans", __name__, "\ndict_arguments = ", dict_arguments
#
  erreur = dict_arguments["code_de_retour"]
#
  if not erreur :
#
    rep_calc_logiciel = dict_arguments ["rep_calc_LOGICIEL"]
#
    type_fonc = dict_arguments ["type_fonc"]
#
    if type_fonc == 1 :
#
# 3. Mode : creation du sous-repertoire de calcul pour HOMARD
#
#      print blabla, "2, :", "\ndict_arguments :", dict_arguments
      erreur = aster_homard_2 (dict_arguments)
#
    else :
#
# 4. En mode execution de homard
#
# 4.1. Decodage et stockage des arguments restants
#
      if not erreur :
#        print blabla, "3, :", "\nl_arguments :", l_arguments
        aux = l_arguments[0:1]+l_arguments[3:]
#        print blabla, "3, :", "\naux :", aux
        dict_arguments = aster_homard_3 (aux)
        erreur = dict_arguments["code_de_retour"]
#        print blabla, "3, :", "\ndict_arguments :", dict_arguments
#
# 4.2. On passe dans le sous-repertoire de calcul pour homard
#
      if not erreur :
        codret_partiel = [0]
        try :
          os.chdir(rep_calc_logiciel)
        except os.error, codret_partiel :
          print "Code d'erreur de chdir : ", codret_partiel[0], ":", codret_partiel[1]
        if codret_partiel[0] != 0 :
          erreur = 2
#
# 4.3. Recuperation des options dans le fichier de configuration
#
      if not erreur :
        fic_conf = environnement["fic_conf"]
#        print blabla, "4, :", "\nfic_conf :", fic_conf
        variables_conf = aster_homard_4 (fic_conf)
        erreur = variables_conf["code_de_retour"]
#
# 4.4. Mise en place des liens
#
      if not erreur :
#        print blabla, "5, :", "\nrep_calc_aster :", rep_calc_aster, "\ndict_arguments :", dict_arguments, "\nvariables_conf :", variables_conf
        erreur = aster_homard_5 (rep_calc_aster, dict_arguments, variables_conf)
#
# 4.5. Execution
#
      if not erreur :
#        print blabla, "6, :", "\nenvironnement :", environnement, "\ndict_arguments :", dict_arguments, "\nvariables_conf :", variables_conf
        code_retour_exec = aster_homard_6 (environnement, dict_arguments, variables_conf)
#
# 4.6. Manipulation sur les resultats produits
#
      if not erreur :
#        print blabla, "7, :", "\nenvironnement :", environnement, "\ndict_arguments :", dict_arguments, "\nvariables_conf :", variables_conf, "\ncode_retour_exec :", code_retour_exec
        erreur = aster_homard_7 (environnement, dict_arguments, variables_conf, code_retour_exec)
        if code_retour_exec != 0 :
          erreur = 10
#
# 4.7. Apres une adaptation en mode perso, relance de HOMARD pour les figures
#
      if not erreur :
        if ( dict_arguments["PERSO"] == "oui" ) and ( variables_conf["ModeHOMA"] == 1 ) :
#          print blabla, "8, :", "\nenvironnement :", environnement, "\ndict_arguments :", dict_arguments, "\nvariables_conf :", variables_conf
          erreur = aster_homard_8 (environnement, dict_arguments, variables_conf)
#
# 5. La fin
#
  os.chdir(rep_calc_aster)
#
  if erreur :
    message_erreur = str(erreur)
#
  return message_erreur
#
#
#=======================================================================================
#=======================================================================================
#
#
if __name__ == "__main__" :
#
  from aster_homard_utilitaires import verif
#
# 1. ==> Rcupration des arguments
#
  T1 = "/tmp/q"
  T1_refe = "1"
  message_erreur_test = aster_homard (T1)
  verif ("Test T1", T1_refe, message_erreur_test)
#
  sys.exit(message_erreur_test)
